==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/AudioTrackArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.AudioTrackArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Represents an audio track in the asset.
 * @property dashSettings The DASH specific setting for the audio track.
 * @property displayName The display name of the audio track on a video player. In HLS, this maps to the NAME attribute of EXT-X-MEDIA.
 * @property fileName The file name to the source file. This file is located in the storage container of the asset.
 * @property hlsSettings The HLS specific setting for the audio track.
 * @property languageCode The RFC5646 language code for the audio track.
 * @property mpeg4TrackId The MPEG-4 audio track ID for the audio track.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.AudioTrack'.
 */
public data class AudioTrackArgs(
    public val dashSettings: Output<DashSettingsArgs>? = null,
    public val displayName: Output<String>? = null,
    public val fileName: Output<String>? = null,
    public val hlsSettings: Output<HlsSettingsArgs>? = null,
    public val languageCode: Output<String>? = null,
    public val mpeg4TrackId: Output<Int>? = null,
    public val odataType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.AudioTrackArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.AudioTrackArgs =
        com.pulumi.azurenative.media.inputs.AudioTrackArgs.builder()
            .dashSettings(dashSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .fileName(fileName?.applyValue({ args0 -> args0 }))
            .hlsSettings(hlsSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .languageCode(languageCode?.applyValue({ args0 -> args0 }))
            .mpeg4TrackId(mpeg4TrackId?.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AudioTrackArgs].
 */
@PulumiTagMarker
public class AudioTrackArgsBuilder internal constructor() {
    private var dashSettings: Output<DashSettingsArgs>? = null

    private var displayName: Output<String>? = null

    private var fileName: Output<String>? = null

    private var hlsSettings: Output<HlsSettingsArgs>? = null

    private var languageCode: Output<String>? = null

    private var mpeg4TrackId: Output<Int>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value The DASH specific setting for the audio track.
     */
    @JvmName("mqblofvkjklyyxft")
    public suspend fun dashSettings(`value`: Output<DashSettingsArgs>) {
        this.dashSettings = value
    }

    /**
     * @param value The display name of the audio track on a video player. In HLS, this maps to the NAME attribute of EXT-X-MEDIA.
     */
    @JvmName("wjsptpwhiphaupah")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value The file name to the source file. This file is located in the storage container of the asset.
     */
    @JvmName("dbisutpghbxexpuj")
    public suspend fun fileName(`value`: Output<String>) {
        this.fileName = value
    }

    /**
     * @param value The HLS specific setting for the audio track.
     */
    @JvmName("qiyovfbafwtijesn")
    public suspend fun hlsSettings(`value`: Output<HlsSettingsArgs>) {
        this.hlsSettings = value
    }

    /**
     * @param value The RFC5646 language code for the audio track.
     */
    @JvmName("smsumppsbiynebjv")
    public suspend fun languageCode(`value`: Output<String>) {
        this.languageCode = value
    }

    /**
     * @param value The MPEG-4 audio track ID for the audio track.
     */
    @JvmName("fiqlktdubdfjrpak")
    public suspend fun mpeg4TrackId(`value`: Output<Int>) {
        this.mpeg4TrackId = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AudioTrack'.
     */
    @JvmName("bghsapwoynnkahnx")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The DASH specific setting for the audio track.
     */
    @JvmName("thaotrrhjnrndmkl")
    public suspend fun dashSettings(`value`: DashSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dashSettings = mapped
    }

    /**
     * @param argument The DASH specific setting for the audio track.
     */
    @JvmName("qmtoueygqdmmyvhu")
    public suspend fun dashSettings(argument: suspend DashSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = DashSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dashSettings = mapped
    }

    /**
     * @param value The display name of the audio track on a video player. In HLS, this maps to the NAME attribute of EXT-X-MEDIA.
     */
    @JvmName("pttiloqdjnvltsrl")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value The file name to the source file. This file is located in the storage container of the asset.
     */
    @JvmName("urjdjkquafkrtbtf")
    public suspend fun fileName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileName = mapped
    }

    /**
     * @param value The HLS specific setting for the audio track.
     */
    @JvmName("elsdfhhyuukugvuy")
    public suspend fun hlsSettings(`value`: HlsSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hlsSettings = mapped
    }

    /**
     * @param argument The HLS specific setting for the audio track.
     */
    @JvmName("ktrgicxwouabhkbv")
    public suspend fun hlsSettings(argument: suspend HlsSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = HlsSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hlsSettings = mapped
    }

    /**
     * @param value The RFC5646 language code for the audio track.
     */
    @JvmName("apfxdxdrpfrhqrcp")
    public suspend fun languageCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.languageCode = mapped
    }

    /**
     * @param value The MPEG-4 audio track ID for the audio track.
     */
    @JvmName("mptqnuuxpqwaqfaq")
    public suspend fun mpeg4TrackId(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpeg4TrackId = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AudioTrack'.
     */
    @JvmName("lpuwvgyybkbnkwhy")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): AudioTrackArgs = AudioTrackArgs(
        dashSettings = dashSettings,
        displayName = displayName,
        fileName = fileName,
        hlsSettings = hlsSettings,
        languageCode = languageCode,
        mpeg4TrackId = mpeg4TrackId,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/AudioTrackArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.AudioTrackArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Represents an audio track in the asset.
 * @property dashSettings The DASH specific setting for the audio track.
 * @property displayName The display name of the audio track on a video player. In HLS, this maps to the NAME attribute of EXT-X-MEDIA.
 * @property fileName The file name to the source file. This file is located in the storage container of the asset.
 * @property hlsSettings The HLS specific setting for the audio track.
 * @property languageCode The RFC5646 language code for the audio track.
 * @property mpeg4TrackId The MPEG-4 audio track ID for the audio track.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.AudioTrack'.
 */
public data class AudioTrackArgs(
    public val dashSettings: Output<DashSettingsArgs>? = null,
    public val displayName: Output<String>? = null,
    public val fileName: Output<String>? = null,
    public val hlsSettings: Output<HlsSettingsArgs>? = null,
    public val languageCode: Output<String>? = null,
    public val mpeg4TrackId: Output<Int>? = null,
    public val odataType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.AudioTrackArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.AudioTrackArgs =
        com.pulumi.azurenative.media.inputs.AudioTrackArgs.builder()
            .dashSettings(dashSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .fileName(fileName?.applyValue({ args0 -> args0 }))
            .hlsSettings(hlsSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .languageCode(languageCode?.applyValue({ args0 -> args0 }))
            .mpeg4TrackId(mpeg4TrackId?.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AudioTrackArgs].
 */
@PulumiTagMarker
public class AudioTrackArgsBuilder internal constructor() {
    private var dashSettings: Output<DashSettingsArgs>? = null

    private var displayName: Output<String>? = null

    private var fileName: Output<String>? = null

    private var hlsSettings: Output<HlsSettingsArgs>? = null

    private var languageCode: Output<String>? = null

    private var mpeg4TrackId: Output<Int>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value The DASH specific setting for the audio track.
     */
    @JvmName("utfibgsijlsmxefi")
    public suspend fun dashSettings(`value`: Output<DashSettingsArgs>) {
        this.dashSettings = value
    }

    /**
     * @param value The display name of the audio track on a video player. In HLS, this maps to the NAME attribute of EXT-X-MEDIA.
     */
    @JvmName("rdyxgeeiogpeaseb")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value The file name to the source file. This file is located in the storage container of the asset.
     */
    @JvmName("ymqfhgmmiubgkeow")
    public suspend fun fileName(`value`: Output<String>) {
        this.fileName = value
    }

    /**
     * @param value The HLS specific setting for the audio track.
     */
    @JvmName("ugigpurjcrenluwm")
    public suspend fun hlsSettings(`value`: Output<HlsSettingsArgs>) {
        this.hlsSettings = value
    }

    /**
     * @param value The RFC5646 language code for the audio track.
     */
    @JvmName("xxhnwtviygaupwyh")
    public suspend fun languageCode(`value`: Output<String>) {
        this.languageCode = value
    }

    /**
     * @param value The MPEG-4 audio track ID for the audio track.
     */
    @JvmName("ltyboetwjaujhuiy")
    public suspend fun mpeg4TrackId(`value`: Output<Int>) {
        this.mpeg4TrackId = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AudioTrack'.
     */
    @JvmName("pdrimbfpbjcgaafh")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The DASH specific setting for the audio track.
     */
    @JvmName("hhskpjaipmflxvnf")
    public suspend fun dashSettings(`value`: DashSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dashSettings = mapped
    }

    /**
     * @param argument The DASH specific setting for the audio track.
     */
    @JvmName("iwcffqfirerrqpbg")
    public suspend fun dashSettings(argument: suspend DashSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = DashSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dashSettings = mapped
    }

    /**
     * @param value The display name of the audio track on a video player. In HLS, this maps to the NAME attribute of EXT-X-MEDIA.
     */
    @JvmName("kawnqkhklajbvglw")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value The file name to the source file. This file is located in the storage container of the asset.
     */
    @JvmName("wvluefoqjmpwsheb")
    public suspend fun fileName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileName = mapped
    }

    /**
     * @param value The HLS specific setting for the audio track.
     */
    @JvmName("thcwutmuqmerhtkf")
    public suspend fun hlsSettings(`value`: HlsSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hlsSettings = mapped
    }

    /**
     * @param argument The HLS specific setting for the audio track.
     */
    @JvmName("mbqhjabulmykjeql")
    public suspend fun hlsSettings(argument: suspend HlsSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = HlsSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hlsSettings = mapped
    }

    /**
     * @param value The RFC5646 language code for the audio track.
     */
    @JvmName("ucjcqygrvfquqywu")
    public suspend fun languageCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.languageCode = mapped
    }

    /**
     * @param value The MPEG-4 audio track ID for the audio track.
     */
    @JvmName("dueylcmgfbtkelcf")
    public suspend fun mpeg4TrackId(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpeg4TrackId = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AudioTrack'.
     */
    @JvmName("pmewvyeyfcghybdl")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): AudioTrackArgs = AudioTrackArgs(
        dashSettings = dashSettings,
        displayName = displayName,
        fileName = fileName,
        hlsSettings = hlsSettings,
        languageCode = languageCode,
        mpeg4TrackId = mpeg4TrackId,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
    )
}
